//
// Copyright (c) 2002
// Ronald Kevin Burton
//
// This material is provided "as is", with absolutely no warranty expressed
// or implied. This software is provided solely as part of ".NET Common Language
// Runtime Unleashed" to help illustrate concepts and principles described in 
// that book. Any use is at your own risk.
//
// Permission to use or copy this software for any purpose is hereby granted 
// without fee, provided the above notices are retained on all copies.
// Permission to modify the code and to distribute modified code is granted,
// provided the above notices are retained, and a notice that the code was
// modified is included with the above copyright notice.
//
// 
using System;
using System.Collections;

namespace FrameworkLibraries
{
	public class EnvironmentMain 
	{
		static void Main(string [] args)
		{
			Console.WriteLine("Command line: {0}", Environment.CommandLine);
			Console.WriteLine("Directory: {0}", Environment.CurrentDirectory);
			Console.WriteLine("Exit Code: {0}", Environment.ExitCode);
			Console.WriteLine("Machine name: {0}", Environment.MachineName);
			Console.Write("NewLine: ");
			string nl = Environment.NewLine;
			foreach(byte c in nl)
			{
				Console.Write("0x{0:X} ", c);
			}
			Console.WriteLine();
			Console.WriteLine("OS Version: {0}", Environment.OSVersion);
			Console.WriteLine("Stack trace: {0}", Environment.StackTrace);
			Console.WriteLine("System directory: {0}", Environment.SystemDirectory);
			Console.WriteLine("Tick count: {0}", Environment.TickCount);
			Console.WriteLine("User domain name: {0}", Environment.UserDomainName);
			Console.WriteLine("Interactive: {0}", Environment.UserInteractive);
			Console.WriteLine("User name: {0}", Environment.UserName);
			Console.WriteLine("Version: {0}", Environment.Version);
			Console.WriteLine("Working set: {0}", Environment.WorkingSet);
			Console.WriteLine("Expand environment variables: {0}", 
				              Environment.ExpandEnvironmentVariables("PATH=%PATH%;INCLUDE=%INCLUDE%"));
			Console.Write("Command line: ");
			string [] ca = Environment.GetCommandLineArgs();
			foreach(string s in ca)
				Console.Write("{0} ", s);
			Console.WriteLine();
			Console.WriteLine("PATH: {0}", Environment.GetEnvironmentVariable("PATH"));
			IDictionary env = Environment.GetEnvironmentVariables();
			Console.WriteLine("Environment: ");
			foreach(DictionaryEntry de in env)
				Console.WriteLine("{0} {1}", de.Key, de.Value);
			Console.WriteLine("Application Data: {0}", Environment.GetFolderPath(Environment.SpecialFolder.ApplicationData));
			Console.WriteLine("Common Application Data: {0}", Environment.GetFolderPath(Environment.SpecialFolder.CommonApplicationData));
			Console.WriteLine("Common Program Files: {0}", Environment.GetFolderPath(Environment.SpecialFolder.CommonProgramFiles));
			Console.WriteLine("Cookies: {0}", Environment.GetFolderPath(Environment.SpecialFolder.Cookies));
			Console.WriteLine("DesktopDirectory: {0}", Environment.GetFolderPath(Environment.SpecialFolder.DesktopDirectory));
			Console.WriteLine("Favorites: {0}", Environment.GetFolderPath(Environment.SpecialFolder.Favorites));
			Console.WriteLine("History: {0}", Environment.GetFolderPath(Environment.SpecialFolder.History));
			Console.WriteLine("InternetCache: {0}", Environment.GetFolderPath(Environment.SpecialFolder.InternetCache));
			Console.WriteLine("LocalApplicationData: {0}", Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData));
			Console.WriteLine("Personal: {0}", Environment.GetFolderPath(Environment.SpecialFolder.Personal));
			Console.WriteLine("ProgramFiles: {0}", Environment.GetFolderPath(Environment.SpecialFolder.ProgramFiles));
			Console.WriteLine("Programs: {0}", Environment.GetFolderPath(Environment.SpecialFolder.Programs));
			Console.WriteLine("Recent: {0}", Environment.GetFolderPath(Environment.SpecialFolder.Recent));
			Console.WriteLine("SendTo: {0}", Environment.GetFolderPath(Environment.SpecialFolder.SendTo));
			Console.WriteLine("StartMenu: {0}", Environment.GetFolderPath(Environment.SpecialFolder.StartMenu));
			Console.WriteLine("Startup: {0}", Environment.GetFolderPath(Environment.SpecialFolder.Startup));
			Console.WriteLine("System: {0}", Environment.GetFolderPath(Environment.SpecialFolder.System));
			Console.WriteLine("Templates: {0}", Environment.GetFolderPath(Environment.SpecialFolder.Templates));
			string [] ld = Environment.GetLogicalDrives();
			foreach(string s in ld)
				Console.Write("{0} ", s);

			Environment.Exit(1);
		}
	}
}