//
// Copyright (c) 2002
// Ronald Kevin Burton
//
// This material is provided "as is", with absolutely no warranty expressed
// or implied. This software is provided solely as part of ".NET Common Language
// Runtime Unleashed" to help illustrate concepts and principles described in 
// that book. Any use is at your own risk.
//
// Permission to use or copy this software for any purpose is hereby granted 
// without fee, provided the above notices are retained on all copies.
// Permission to modify the code and to distribute modified code is granted,
// provided the above notices are retained, and a notice that the code was
// modified is included with the above copyright notice.
//
// 
using System;
using System.ComponentModel;
using System.Globalization;

namespace FrameworkLibraries
{
	[TypeConverter(typeof(ComplexConverter))]
	public class Complex
	{
		private double re;
		private double im;
		public Complex(double re, double im)
		{
			this.re = re;
			this.im = im;
		}
		public double Real
		{
			get
			{
				return re;
			}
			set
			{
				re = value;
			}
		}
		public double Imaginary
		{
			get
			{
				return im;
			}
			set
			{
				im = value;
			}
		}
	}
	public class ComplexConverter : TypeConverter
	{
		// Overrides the CanConvertFrom method of TypeConverter.
		// The ITypeDescriptorContext interface provides the context for the
		// conversion. Typically this interface is used at design time to 
		// provide information about the design-time container.
		public override bool CanConvertFrom(ITypeDescriptorContext context, 
			Type sourceType) 
		{
			if (sourceType == typeof(string)) 
			{
				return true;
			}
			return base.CanConvertFrom(context, sourceType);
		}
		// Overrides the ConvertFrom method of TypeConverter.
		public override object ConvertFrom(ITypeDescriptorContext context, 
			CultureInfo culture, object value) 
		{
			if (value is string) 
			{
				string[] v = ((string)value).Split(new char[] {','});
				return new Complex(double.Parse(v[0]), double.Parse(v[1]));
			}
			return base.ConvertFrom(context, culture, value);
		}
		// Overrides the ConvertTo method of TypeConverter.
		public override object ConvertTo(ITypeDescriptorContext context, 
			CultureInfo culture, object value, Type destinationType) 
		{  
			if (destinationType == typeof(string)) 
			{
				return ((Complex)value).Real + "," + ((Complex)value).Imaginary;
			}
			return base.ConvertTo(context, culture, value, destinationType);
		}
	}
	public class VersionMain 
	{
		static void Main(string [] args)
		{
			Complex c = (Complex)TypeDescriptor.GetConverter(typeof(Complex)).ConvertFromString("1.0,2.0");
			string ds = (string)TypeDescriptor.GetConverter(c).ConvertToString(c);
			Console.WriteLine("{0},{1} <-> {2}", c.Real, c.Imaginary, ds);
		}
	}
}