//
// Copyright (c) 2002
// Ronald Kevin Burton
//
// This material is provided "as is", with absolutely no warranty expressed
// or implied. This software is provided solely as part of ".NET Common Language
// Runtime Unleashed" to help illustrate concepts and principles described in 
// that book. Any use is at your own risk.
//
// Permission to use or copy this software for any purpose is hereby granted 
// without fee, provided the above notices are retained on all copies.
// Permission to modify the code and to distribute modified code is granted,
// provided the above notices are retained, and a notice that the code was
// modified is included with the above copyright notice.
//
// 
using System;
using System.IO;
using System.Xml;

namespace FrameworkLibraries
{
	public class ReadXmlFile
	{
		public static void Main(string [] args)
		{
			string document = "booklist.xml";
			ReadXmlFile readXml = new ReadXmlFile();
			if ( args.Length > 0 ) 
			{
				foreach(string arg in args)
					readXml.Process(arg);
			}
			else
				readXml.Process(document);
		}

		public void Process(String document)
		{
			XmlTextReader reader = null;
			try
			{
				// Load the file with an XmlTextReader
				Console.WriteLine ("Reading file {0} ...", document);
				reader = new XmlTextReader (document);
				Console.WriteLine ("File {0} read successfully ...", document);

				// Process the supplied XML file
				Console.WriteLine ("Processing ...");
				Console.WriteLine ();
				FormatXml(reader, document);
			}
			catch (Exception e)
			{
				Console.WriteLine ("Failed to read the file {0}", document);
				Console.WriteLine ("Exception: {0}", e.ToString());
			}

			finally
			{
				Console.WriteLine();
				Console.WriteLine("Processing of the file {0} complete.", document);
				// Finished with XmlTextReader
				if (reader != null)
					reader.Close();
			}
		}

		private static void FormatXml (XmlReader reader, string filename)
		{
			int declarationCount=0;
			int piCount=0;
			int docCount=0;
			int commentCount=0;
			int elementCount=0;
			int attributeCount=0;
			int textCount=0;
			int whitespaceCount=0;

			while (reader.Read())
			{
				switch (reader.NodeType)
				{
					case XmlNodeType.XmlDeclaration:
						Format (reader, "XmlDeclaration");
						declarationCount++;
						break;
					case XmlNodeType.ProcessingInstruction:
						Format (reader, "ProcessingInstruction");
						piCount++;
						break;
					case XmlNodeType.DocumentType:
						Format (reader, "DocumentType");
						docCount++;
						break;
					case XmlNodeType.Comment:
						Format (reader, "Comment");
						commentCount++;
						break;
					case XmlNodeType.Element:
						Format (reader, "Element");
						elementCount++;
						if (reader.HasAttributes)
							attributeCount += reader.AttributeCount;
						break;
					case XmlNodeType.Text:
						Format (reader, "Text");
						textCount++;
						break;
					case XmlNodeType.Whitespace:
						whitespaceCount++;
						break;
				}
			}

			// Display the Statistics for the file.
			Console.WriteLine ();
			Console.WriteLine("Statistics for {0} file", filename);
			Console.WriteLine ();
			Console.WriteLine("XmlDeclaration: {0}",declarationCount++);
			Console.WriteLine("ProcessingInstruction: {0}",piCount++);
			Console.WriteLine("DocumentType: {0}",docCount++);
			Console.WriteLine("Comment: {0}",commentCount++);
			Console.WriteLine("Element: {0}",elementCount++);
			Console.WriteLine("Attribute: {0}",attributeCount++);
			Console.WriteLine("Text: {0}",textCount++);
			Console.WriteLine("Whitespace: {0}",whitespaceCount++);
		}

		private static void Format(XmlReader reader, String nodeType)
		{
			// Format the output
			Console.Write(reader.Depth + " ");
			Console.Write(reader.AttributeCount + " ");
			for (int i=0; i < reader.Depth; i++)
			{
				Console.Write('\t');
			}

			Console.Write(reader.Prefix + nodeType + "<" + reader.Name + ">" + reader.Value);

			// Display the attributes values for the current node
			if (reader.HasAttributes)
			{
				Console.Write(" Attributes:");

				for (int j=0; j < reader.AttributeCount; j++)
				{
					Console.Write(" [{0}] " + reader[j], j);
				}
			}
			Console.WriteLine();
		}

	}
}
